==> dove.max.sdk-1.1.3.tgz: package/src/dove.sdk/util/update.js <==
import { common } from './common'
import { communication } from './communication'
import { loaderWrapper } from './loaderWrapper'

// 自动更新设置
/**
 * appId, 指定AppID
 * promptText, 指定提示说明
 * getDataCB. 获得数据后的处理方式
 * cb, 内置处理完成后，回调处理
 */
var uu$ = {}
uu$.hasUpdateChecked = false
uu$.checkUpdate = function (appId, promptText, getDataCB, cb) {
  try {
    var t$ = this
    var b$ = common.getBSb$()
    var $ = common.getJQuery$()

    var _checkUpdate = function (data) {
      try {
        var lastVersion = data.checkUpdate.lastVersion || ''
        var updateURL = data.checkUpdate.updateURL || ''

        // 检查是否有队苹果Apple 应用或者不使用
        var enableForMacOSAppStore = data.checkUpdate.enableForMacOSAppStore !==
          false
        var enableForElectron = data.checkUpdate.enableForElectron !== false
        var enableForNoMacOSAppStore = true

        enableForMacOSAppStore = enableForMacOSAppStore && b$.pIsUseMacCocoEngine &&
          b$.App.getSandboxEnable()
        enableForElectron = enableForElectron && b$.pIsUseElectron
        enableForNoMacOSAppStore = b$.pIsUseMacCocoEngine && !b$.App.getSandboxEnable()

        // 任意符合两种模式都可以启用
        if (enableForMacOSAppStore || enableForElectron || enableForNoMacOSAppStore) {
          // 比较
          var curAppVersion = b$.App.getAppVersion()
          console.log('last:' + lastVersion + ',cur:' + curAppVersion)
          if (common.compareVersion(lastVersion, curAppVersion) === 1) {
            var foundNewVersion = promptText || data.checkUpdate.prompt ||
              'The new version has been released.'
            alert(foundNewVersion)
            updateURL !== '' && b$.App.open(updateURL)
            cb && cb(data)
          }
        }
      } catch (e) {
        console.error(e)
      }
    }

    // 尝试读取服务器配置
    var jsonFile = appId || b$.App.getAppId() + '.json'
    var serverUrl = 'https://romanysoft.github.io/assert-config/configs/' + jsonFile
    $.getJSON(serverUrl, function (data) {
      if (t$.hasUpdateChecked) return
      t$.hasUpdateChecked = true

      data = typeof data === 'object' ? data : {}
      data = data instanceof Array ? {
        'data': data
      } : data
      getDataCB && getDataCB(data)
      _checkUpdate(data)
    })
  } catch (e) {
    console.error(e)
  }
}

// 检测及汇报状态
uu$.checkStartInfo = function (info) {
  var b$ = common.getBSb$()
  if (b$.pN) {
    communication.reportInfo({
      'SYS_state': 'Starting...',
      'Add_info': info || {}
    })
  }
}

// 检测在线补丁包
uu$.checkPatches = function (info) {
  loaderWrapper.RTY_3rd_Ensure.ensure({
    js: 'https://romanysoft.github.io/assert-config/patchs/config.js'
  }, function () {})
}

// 内核加入自启动部分代码
try {
  var $ = common.getJQuery$()
  var b$ = common.getBSb$()
  if ($) {
    $(document).ready(function () {
      console.log(
        '-------------Delayed loading method, do not reflect here-------')

      // / 默认添加提示新版本
      setTimeout(function () {
        uu$.checkStartInfo()

        if (b$.App.getSandboxEnable() && b$.App.getAppRunOnOS() === 'MacOSX') {
          console.log('------------- common app starting .... -------')
        } else {
          uu$.checkUpdate()
          // uu$.checkPatches()
        }
      }, 35 * 1000) // 35sec
    })
  }
} catch (e) {
  console.error(e)
}

// -----------------------------------------------
const update = uu$
export {
  update
}

==> dove.max.sdk-20171207.9.17.tgz: package/src/dove.sdk/util/update.js <==
import { common } from './common'
import { communication } from './communication'
import { loaderWrapper } from './loaderWrapper'
import _ from 'lodash'

// 自动更新设置
/**
 * appId, 指定AppID
 * promptText, 指定提示说明
 * getDataCB. 获得数据后的处理方式
 * foundNewVersionCallback, 内置处理完成后，回调处理
 */
var uu$ = {}
uu$.hasUpdateChecked = false
uu$.checkUpdate = function (appId, promptText, getDataCB, foundNewVersionCallback) {
  try {
    var t$ = this
    var b$ = common.getBSb$()
    // var $ = common.getJQuery$()

    var _checkUpdate = function (data) {
      // 先检测是否有checkUpdate属性
      if (!data.checkUpdate) return

      try {
        var lastVersion = data.checkUpdate.lastVersion || ''
        var updateURL = data.checkUpdate.updateURL || ''

        // 检查是否有队苹果Apple 应用或者不使用
        var enableForMacOSAppStore = data.checkUpdate.enableForMacOSAppStore !==
          false
        var enableForElectron = data.checkUpdate.enableForElectron !== false
        var enableForNoMacOSAppStore = true

        enableForMacOSAppStore = enableForMacOSAppStore && b$.pIsUseMacCocoEngine &&
          b$.App.getSandboxEnable()
        enableForElectron = enableForElectron && b$.pIsUseElectron
        enableForNoMacOSAppStore = b$.pIsUseMacCocoEngine && !b$.App.getSandboxEnable()

        // 任意符合两种模式都可以启用
        if (enableForMacOSAppStore || enableForElectron || enableForNoMacOSAppStore) {
          // 比较
          var curAppVersion = b$.App.getAppVersion()
          console.log('last:' + lastVersion + ',cur:' + curAppVersion)
          if (common.compareVersion(lastVersion, curAppVersion) === 1) {
            var foundNewVersion = promptText || data.checkUpdate.prompt ||
              'The new version has been released.'

            if (_.isFunction(foundNewVersionCallback)) {
              foundNewVersionCallback(data)
            } else {
              alert(foundNewVersion)
              updateURL !== '' && b$.App.open(updateURL)
            }
          }
        }
      } catch (e) {
        console.error(e)
      }
    }

    // 尝试读取服务器配置
    if (t$.hasUpdateChecked) return

    const info = {
      machine: b$.App.getSerialNumber(),
      os: b$.App.getAppRunOnOS(),
      sandbox: b$.App.getSandboxEnable(),
      appId: b$.App.getAppId(),
      appName: b$.App.getAppName(),
      appVersion: b$.App.getAppVersion()
    }

    // 从远程服务中获取更新信息
    console.log('#[get update info] .......')
    communication.commitMessage('/services/get_update_info', info, (_data) => {
      t$.hasUpdateChecked = true

      var serverData = _.isObject(_data) ? _data : {}
      serverData = _.isArray(serverData) ? { 'data': serverData } : serverData
      getDataCB && getDataCB(serverData)

      console.log('#[get update info data] .......')
      console.dir(serverData)
      _checkUpdate(serverData['data'])
    })
  } catch (e) {
    console.error(e)
  }
}

// 检测及汇报状态
uu$.checkStartInfo = function (info) {
  var b$ = common.getBSb$()
  if (b$.pN) {
    communication.reportInfo({
      'SYS_state': 'Starting...',
      'Add_info': info || {}
    })
  }
}

// 检测在线补丁包
uu$.checkPatches = function (info) {
  loaderWrapper.RTY_3rd_Ensure.ensure({
    js: 'https://romanysoft.github.io/assert-config/patchs/config.js'
  }, function () {})
}

// -----------------------------------------------
const update = uu$
export {
  update
}
